@@ -20,6 +20,11 @@
 
 using namespace DB;
 
+CategoryMatcher::CategoryMatcher()
+    : _shouldPrepareMatchedSet(false)
+{
+}
+
 QString CategoryMatcher::spaces(int level ) const
 {
     return QString::fromLatin1("").rightJustified(level*3 );
@@ -30,3 +35,4 @@ void DB::CategoryMatcher::setShouldCreateMatchedSet(bool b)
     _shouldPrepareMatchedSet = b;
 }
 
+// vi:expandtab:tabstop=4 shiftwidth=4:
