@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2006 Jesper K. Pedersen <blackie@kde.org>
+/* Copyright (C) 2003-2010 Jesper K. Pedersen <blackie@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -27,12 +27,12 @@
 
 using namespace DB;
 
-FileInfo FileInfo::read( const QString& fileName, DB::ExifMode mode )
+FileInfo FileInfo::read( const DB::FileName& fileName, DB::ExifMode mode )
 {
     return FileInfo( fileName, mode );
 }
 
-DB::FileInfo::FileInfo( const QString& fileName, DB::ExifMode mode )
+DB::FileInfo::FileInfo( const DB::FileName& fileName, DB::ExifMode mode )
     : _angle(0)
 {
 #ifdef HAVE_EXIV2
@@ -42,18 +42,18 @@ DB::FileInfo::FileInfo( const QString& fileName, DB::ExifMode mode )
 #endif
 
 
-    if ( updateDatFromFileTimeStamp(fileName,mode))
-        _date = QFileInfo( fileName ).lastModified();
+    if ( updateDataFromFileTimeStamp(fileName,mode))
+        _date = QFileInfo( fileName.absolute() ).lastModified();
 }
 
-bool DB::FileInfo::updateDatFromFileTimeStamp(const QString& fileName, DB::ExifMode mode)
+bool DB::FileInfo::updateDataFromFileTimeStamp(const DB::FileName& fileName, DB::ExifMode mode)
 {
     // If the date is valid from EXIF reading, then we should not use the time stamp from the file.
     if ( _date.isValid() )
         return false;
 
     // If we are not setting date, then we should of course not set the date
-    if ( (mode & EXIFMODE_DATE) != 0 )
+    if ( (mode & EXIFMODE_DATE) == 0 )
         return false;
 
     // If we are we already have specifies that we want to sent the date (from the ReReadExif dialog), then we of course should.
@@ -70,7 +70,7 @@ bool DB::FileInfo::updateDatFromFileTimeStamp(const QString& fileName, DB::ExifM
 }
 
 #ifdef HAVE_EXIV2
-void DB::FileInfo::parseEXIV2( const QString& fileName )
+void DB::FileInfo::parseEXIV2( const DB::FileName& fileName )
 {
     Exiv2::ExifData map = Exif::Info::instance()->metadata( fileName ).exif;
 
@@ -86,7 +86,9 @@ void DB::FileInfo::parseEXIV2( const QString& fileName )
     if ( map.findKey( Exiv2::ExifKey( "Exif.Image.Orientation" ) ) != map.end() ) {
         const Exiv2::Exifdatum& datum = map["Exif.Image.Orientation"];
 
-        int orientation =  datum.toLong();
+        int orientation = 0;
+        if (datum.count() > 0)
+            orientation =  datum.toLong();
         _angle = orientationToAngle( orientation );
     }
 
@@ -114,21 +116,9 @@ QDateTime FileInfo::fetchEXIV2Date( Exiv2::ExifData& map, const char* key )
 }
 #endif
 
-void DB::FileInfo::parseKFileMetaInfo( const QString& fileName )
+void DB::FileInfo::parseKFileMetaInfo( const DB::FileName& fileName )
 {
-    QString tempFileName( fileName );
-#ifdef REMOVED_FOR_SOME_REASON_ALSO_IN_KDE3
-    if ( Util::isCRW( fileName ) ) {
-      QString dirName = QFileInfo( fileName ).path();
-      QString baseName = QFileInfo( fileName ).baseName();
-      tempFileName = dirName + QString::fromLatin1("/") + baseName + QString::fromLatin1( ".thm" );
-      QFileInfo tempFile (tempFileName);
-      if ( !tempFile.exists() )
-          tempFileName = dirName + QString::fromLatin1("/") + baseName + QString::fromLatin1( ".THM" );
-    }
-#endif
-
-    KFileMetaInfo metainfo( tempFileName );
+    KFileMetaInfo metainfo( fileName.absolute() );
     if ( !metainfo.isValid() )
         return;
 
@@ -169,3 +159,4 @@ int DB::FileInfo::orientationToAngle( int orientation )
     return 0;
 }
 
+// vi:expandtab:tabstop=4 shiftwidth=4:
