@@ -18,13 +18,12 @@
 #include "SearchDialog.h"
 #include <klocale.h>
 #include <qlayout.h>
-#include <q3vgroupbox.h>
+#include <QGroupBox>
 #include <qcheckbox.h>
 #include <QHBoxLayout>
 #include <QVBoxLayout>
 #include "Exif/Database.h"
-#include <q3grid.h>
-
+#include <QGridLayout>
 #include <qlabel.h>
 #include <qspinbox.h>
 #include <QScrollArea>
@@ -47,32 +46,43 @@ Exif::SearchDialog::SearchDialog( QWidget* parent )
     // Iso, Exposure, Aperture, FNumber
     QHBoxLayout* hlay = new QHBoxLayout;
     vlay->addLayout( hlay );
-    Q3Grid* grid = new Q3Grid( 4, settings );
-    grid->setSpacing( 6 );
-    hlay->addWidget( grid );
+    QGridLayout* gridLayout = new QGridLayout;
+    gridLayout->setSpacing( 6 );
+    hlay->addLayout( gridLayout );
     hlay->addStretch( 1 );
 
-    makeISO( grid );
-    makeExposureTime( grid );
+    makeISO( gridLayout );
+    makeExposureTime( gridLayout );
+    hlay->addSpacing(30);
 
-    grid = new Q3Grid( 4, settings );
-    grid->setSpacing( 6 );
-    hlay->addWidget( grid );
+    gridLayout = new QGridLayout;
+    gridLayout->setSpacing( 6 );
+    hlay->addLayout( gridLayout );
     hlay->addStretch( 1 );
-    _apertureValue = makeApertureOrFNumber( i18n( "Aperture Value" ), QString::fromLatin1( "Exif_Photo_ApertureValue" ), grid );
-    _fNumber = makeApertureOrFNumber( i18n( "F Number" ), QString::fromLatin1( "Exif_Photo_FNumber" ), grid );
+    _apertureValue = makeApertureOrFNumber( i18n( "Aperture Value" ), QString::fromLatin1( "Exif_Photo_ApertureValue" ), gridLayout, 0 );
+    _fNumber = makeApertureOrFNumber( i18n( "F Number" ), QString::fromLatin1( "Exif_Photo_FNumber" ), gridLayout, 1 );
+
+    hlay->addSpacing(30);
 
     // Focal length
-    grid = new Q3Grid( 4, settings );
-    grid->setSpacing( 6 );
-    hlay->addWidget( grid );
+    QHBoxLayout* focalLayout = new QHBoxLayout;
+    focalLayout->setSpacing( 6 );
+    hlay->addLayout( focalLayout );
     hlay->addStretch( 1 );
-    new QLabel( i18n( "Focal Length" ), grid );
-    _fromFocalLength = new QSpinBox( grid );
+
+    QLabel* label = new QLabel( i18n( "Focal Length" ) );
+    focalLayout->addWidget(label);
+
+    _fromFocalLength = new QSpinBox;
+    focalLayout->addWidget(_fromFocalLength);
     _fromFocalLength->setRange( 0, 10000 );
     _fromFocalLength->setSingleStep( 10 );
-    new QLabel( i18n("to"), grid );
-    _toFocalLength = new QSpinBox( grid );
+
+    label = new QLabel( i18n("to"));
+    focalLayout->addWidget(label);
+
+    _toFocalLength = new QSpinBox;
+    focalLayout->addWidget(_toFocalLength);
     _toFocalLength->setRange( 0, 10000 );
     _toFocalLength->setSingleStep( 10 );
 
@@ -110,7 +120,7 @@ Exif::SearchDialog::SearchDialog( QWidget* parent )
     vlay->addStretch( 1 );
 }
 
-void Exif::SearchDialog::makeISO( Q3Grid* parent )
+void Exif::SearchDialog::makeISO( QGridLayout* layout )
 {
     Exif::RangeWidget::ValueList list;
     list << Exif::RangeWidget::Value( 100, QString::fromLatin1("100") )
@@ -124,10 +134,10 @@ void Exif::SearchDialog::makeISO( Q3Grid* parent )
          << Exif::RangeWidget::Value( 25600, QString::fromLatin1("25600") )
          << Exif::RangeWidget::Value( 51200, QString::fromLatin1("51200") );
 
-    _iso = new RangeWidget( i18n("Iso setting" ), QString::fromLatin1( "Exif_Photo_ISOSpeedRatings" ), list, parent );
+    _iso = new RangeWidget( i18n("Iso setting" ), QString::fromLatin1( "Exif_Photo_ISOSpeedRatings" ), list, layout, 0 );
 }
 
-void Exif::SearchDialog::makeExposureTime( Q3Grid* parent )
+void Exif::SearchDialog::makeExposureTime( QGridLayout* layout )
 {
     QString secs = i18nc( "Example 1.6 secs (as in seconds)", "secs." );
     Exif::RangeWidget::ValueList list;
@@ -185,10 +195,10 @@ void Exif::SearchDialog::makeExposureTime( Q3Grid* parent )
         << Exif::RangeWidget::Value( 25, QString::fromLatin1( "25 %1").arg(secs ) )
         << Exif::RangeWidget::Value( 30, QString::fromLatin1( "30 %1").arg(secs ) );
 
-    _exposureTime = new RangeWidget( i18n("Exposure time" ), QString::fromLatin1( "Exif_Photo_ExposureTime" ), list, parent );
+    _exposureTime = new RangeWidget( i18n("Exposure time" ), QString::fromLatin1( "Exif_Photo_ExposureTime" ), list, layout, 1 );
 }
 
-RangeWidget* Exif::SearchDialog::makeApertureOrFNumber( const QString& text, const QString& key, Q3Grid* parent )
+RangeWidget* Exif::SearchDialog::makeApertureOrFNumber( const QString& text, const QString& key, QGridLayout* layout, int row )
 {
     Exif::RangeWidget::ValueList list;
     list
@@ -223,72 +233,91 @@ RangeWidget* Exif::SearchDialog::makeApertureOrFNumber( const QString& text, con
         << Exif::RangeWidget::Value( 40, QString::fromLatin1( "40" ) )
         << Exif::RangeWidget::Value( 45, QString::fromLatin1( "45" ) );
 
-    return new RangeWidget( text, key, list, parent );
+    return new RangeWidget( text, key, list, layout, row );
 }
 
+#define addSetting(settings,text,num)         \
+    {                                         \
+        QCheckBox* cb = new QCheckBox( i18n( text ), box ); \
+        settings.append( Setting<int>( cb, num ) );         \
+        layout->addWidget(cb);                              \
+    }
+
 QWidget* Exif::SearchDialog::makeExposureProgram( QWidget* parent )
 {
-    Q3VGroupBox* box = new Q3VGroupBox( i18n( "Exposure Program" ), parent );
-    _exposureProgram.append( Setting<int>( new QCheckBox( i18n( "Not defined" ), box ), 0 ) );
-    _exposureProgram.append( Setting<int>( new QCheckBox( i18n( "Manual" ), box ), 1 ) );
-    _exposureProgram.append( Setting<int>( new QCheckBox( i18n( "Normal program" ), box ), 2 ) );
-    _exposureProgram.append( Setting<int>( new QCheckBox( i18n( "Aperture priority" ), box ), 3 ) );
-    _exposureProgram.append( Setting<int>( new QCheckBox( i18n( "Shutter priority" ), box ), 4 ) );
-    _exposureProgram.append( Setting<int>( new QCheckBox( i18n( "Creative program (biased toward depth of field)" ), box ), 5 ) );
-    _exposureProgram.append( Setting<int>( new QCheckBox( i18n( "Action program (biased toward fast shutter speed)" ), box ), 6 ) );
-    _exposureProgram.append( Setting<int>( new QCheckBox( i18n( "Portrait mode (for closeup photos with the background out of focus)" ), box ), 7 ) );
-    _exposureProgram.append( Setting<int>( new QCheckBox( i18n( "Landscape mode (for landscape photos with the background in focus)" ), box ), 8 ) );
+    QGroupBox* box = new QGroupBox( i18n( "Exposure Program" ), parent );
+    QVBoxLayout* layout = new QVBoxLayout(box);
+
+    addSetting( _exposureProgram, "Not defined", 0 );
+    addSetting( _exposureProgram, "Manual", 1 );
+    addSetting( _exposureProgram, "Normal program", 2 );
+    addSetting( _exposureProgram, "Aperture priority", 3 );
+    addSetting( _exposureProgram, "Shutter priority", 4 );
+    addSetting( _exposureProgram, "Creative program (biased toward depth of field)", 5 );
+    addSetting( _exposureProgram, "Action program (biased toward fast shutter speed)", 6 );
+    addSetting( _exposureProgram, "Portrait mode (for closeup photos with the background out of focus)", 7 );
+    addSetting( _exposureProgram, "Landscape mode (for landscape photos with the background in focus)", 8 );
     return box;
 }
 
 QWidget* Exif::SearchDialog::makeOrientation( QWidget* parent )
 {
-    Q3VGroupBox* box = new Q3VGroupBox( i18n( "Orientation" ), parent );
-    _orientation.append( Setting<int>( new QCheckBox( i18n( "Not rotated" ), box ), 0) );
-    _orientation.append( Setting<int>( new QCheckBox( i18n( "Rotated counterclockwise" ), box ), 6 ) );
-    _orientation.append( Setting<int>( new QCheckBox( i18n( "Rotated clockwise" ), box ), 8 ) );
-    _orientation.append( Setting<int>( new QCheckBox( i18n( "Rotated 180 degrees" ), box ), 3 ) );
+    QGroupBox* box = new QGroupBox( i18n( "Orientation" ), parent );
+    QVBoxLayout* layout = new QVBoxLayout(box);
+
+    addSetting( _orientation, "Not rotated", 0);
+    addSetting( _orientation, "Rotated counterclockwise", 6 );
+    addSetting( _orientation, "Rotated clockwise", 8 );
+    addSetting( _orientation, "Rotated 180 degrees", 3 );
     return box;
 }
 
 QWidget* Exif::SearchDialog::makeMeteringMode( QWidget* parent )
 {
-    Q3VGroupBox* box = new Q3VGroupBox( i18n( "Metering Mode" ), parent );
-    _meteringMode.append( Setting<int>( new QCheckBox( i18n( "Unknown" ), box ), 0 ) );
-    _meteringMode.append( Setting<int>( new QCheckBox( i18n( "Average" ), box ), 1 ) );
-    _meteringMode.append( Setting<int>( new QCheckBox( i18n( "CenterWeightedAverage" ), box ), 2 ) );
-    _meteringMode.append( Setting<int>( new QCheckBox( i18n( "Spot" ), box ), 3 ) );
-    _meteringMode.append( Setting<int>( new QCheckBox( i18n( "MultiSpot" ), box ), 4 ) );
-    _meteringMode.append( Setting<int>( new QCheckBox( i18n( "Pattern" ), box ), 5 ) );
-    _meteringMode.append( Setting<int>( new QCheckBox( i18n( "Partial" ), box ), 6 ) );
-    _meteringMode.append( Setting<int>( new QCheckBox( i18n( "Other" ), box ), 255 ) );
+    QGroupBox* box = new QGroupBox( i18n( "Metering Mode" ), parent );
+    QVBoxLayout* layout = new QVBoxLayout(box);
+
+    addSetting( _meteringMode, "Unknown", 0 );
+    addSetting( _meteringMode, "Average", 1 );
+    addSetting( _meteringMode, "CenterWeightedAverage", 2 );
+    addSetting( _meteringMode, "Spot", 3 );
+    addSetting( _meteringMode, "MultiSpot", 4 );
+    addSetting( _meteringMode, "Pattern", 5 );
+    addSetting( _meteringMode, "Partial", 6 );
+    addSetting( _meteringMode, "Other", 255 );
     return box;
 }
 
 QWidget* Exif::SearchDialog::makeContrast( QWidget* parent )
 {
-    Q3VGroupBox* box = new Q3VGroupBox( i18n( "Contrast" ), parent );
-    _contrast.append(Setting<int>( new QCheckBox( i18n( "Normal"), box ), 0 ) );
-    _contrast.append(Setting<int>( new QCheckBox( i18n( "Soft"), box ), 1 ) );
-    _contrast.append(Setting<int>( new QCheckBox( i18n( "Hard"), box ), 2 ) );
+    QGroupBox* box = new QGroupBox( i18n( "Contrast" ), parent );
+    QVBoxLayout* layout = new QVBoxLayout(box);
+
+    addSetting( _contrast, "Normal", 0 );
+    addSetting( _contrast, "Soft", 1 );
+    addSetting( _contrast, "Hard", 2 );
     return box;
 }
 
 QWidget* Exif::SearchDialog::makeSharpness( QWidget* parent )
 {
-    Q3VGroupBox* box = new Q3VGroupBox( i18n( "Sharpness" ), parent );
-    _sharpness.append(Setting<int>( new QCheckBox( i18n( "Normal"), box ), 0 ) );
-    _sharpness.append(Setting<int>( new QCheckBox( i18n( "Soft"), box ), 1 ) );
-    _sharpness.append(Setting<int>( new QCheckBox( i18n( "Hard"), box ), 2 ) );
+    QGroupBox* box = new QGroupBox( i18n( "Sharpness" ), parent );
+    QVBoxLayout* layout = new QVBoxLayout(box);
+
+    addSetting( _sharpness, "Normal", 0 );
+    addSetting( _sharpness, "Soft", 1 );
+    addSetting( _sharpness, "Hard", 2 );
     return box;
 }
 
 QWidget* Exif::SearchDialog::makeSaturation( QWidget* parent )
 {
-    Q3VGroupBox* box = new Q3VGroupBox( i18n( "Saturation" ), parent );
-    _saturation.append(Setting<int>( new QCheckBox( i18n( "Normal"), box ), 0 ) );
-    _saturation.append(Setting<int>( new QCheckBox( i18n( "Low"), box ), 1 ) );
-    _saturation.append(Setting<int>( new QCheckBox( i18n( "High"), box ), 2 ) );
+    QGroupBox* box = new QGroupBox( i18n( "Saturation" ), parent );
+    QVBoxLayout* layout = new QVBoxLayout(box);
+
+    addSetting( _saturation, "Normal", 0 );
+    addSetting( _saturation, "Low", 1 );
+    addSetting( _saturation, "High", 2 );
     return box;
 }
 
@@ -361,3 +390,4 @@ void Exif::SearchDialog::toFocalLengthChanged( int val )
 
 
 #include "SearchDialog.moc"
+// vi:expandtab:tabstop=4 shiftwidth=4:
