@@ -29,7 +29,7 @@
 #include <kfiledialog.h>
 #include <qpushbutton.h>
 #include "Settings/SettingsData.h"
-#include <q3hgroupbox.h>
+#include <QGroupBox>
 #include <kstandarddirs.h>
 #include <kmessagebox.h>
 #include <kfileitem.h>
@@ -41,6 +41,7 @@
 #include "ImageSizeCheckBox.h"
 #include <KTextEdit>
 #include <QStringMatcher>
+#include <QHBoxLayout>
 using namespace HTMLGenerator;
 
 
@@ -128,8 +129,8 @@ void HTMLDialog::createContentPage()
             QCheckBox* cb = new QCheckBox( (*it)->text(), whatToInclude );
             lay3->addWidget( cb, row, col%2 );
             _whatToIncludeMap.insert( (*it)->name(), cb );
-	    pattern->setPattern((*it)->name());
-	    cb->setChecked( pattern->indexIn (selectionsTmp)  >= 0 ? 1 : 0 );
+        pattern->setPattern((*it)->name());
+        cb->setChecked( pattern->indexIn (selectionsTmp)  >= 0 ? 1 : 0 );
             if ( ++col % 2 == 0 )
                 ++row;
         }
@@ -194,17 +195,16 @@ void HTMLDialog::createLayoutPage()
     populateThemesCombo();   
     
     // Image sizes
-    Q3HGroupBox* sizes = new Q3HGroupBox( i18n("Image Sizes"), layoutPage );
+    QGroupBox* sizes = new QGroupBox( i18n("Image Sizes"), layoutPage );
     lay1->addWidget( sizes );
-    QWidget* content = new QWidget( sizes );
-    QGridLayout* lay5 = new QGridLayout( content );
-    ImageSizeCheckBox* size320  = new ImageSizeCheckBox( 320, 200, content );
-    ImageSizeCheckBox* size640  = new ImageSizeCheckBox( 640, 480, content );
-    ImageSizeCheckBox* size800  = new ImageSizeCheckBox( 800, 600, content );
-    ImageSizeCheckBox* size1024 = new ImageSizeCheckBox( 1024, 768, content );
-    ImageSizeCheckBox* size1280 = new ImageSizeCheckBox( 1280, 1024, content );
-    ImageSizeCheckBox* size1600 = new ImageSizeCheckBox( 1600, 1200, content );
-    ImageSizeCheckBox* sizeOrig = new ImageSizeCheckBox( i18n("Full size"), content );
+    QGridLayout* lay5 = new QGridLayout( sizes );
+    ImageSizeCheckBox* size320  = new ImageSizeCheckBox( 320, 200, sizes );
+    ImageSizeCheckBox* size640  = new ImageSizeCheckBox( 640, 480, sizes );
+    ImageSizeCheckBox* size800  = new ImageSizeCheckBox( 800, 600, sizes );
+    ImageSizeCheckBox* size1024 = new ImageSizeCheckBox( 1024, 768, sizes );
+    ImageSizeCheckBox* size1280 = new ImageSizeCheckBox( 1280, 1024, sizes );
+    ImageSizeCheckBox* size1600 = new ImageSizeCheckBox( 1600, 1200, sizes );
+    ImageSizeCheckBox* sizeOrig = new ImageSizeCheckBox( i18n("Full size"), sizes );
 
     {
         int row = 0;
@@ -221,22 +221,22 @@ void HTMLDialog::createLayoutPage()
 
     QString tmp;
     if ((tmp = Settings::SettingsData::instance()->HTMLSizes()) != QString::fromLatin1("")) {
-	QStringMatcher* pattern = new QStringMatcher(QString::fromLatin1("320"));
-	size320->setChecked( pattern->indexIn (tmp) >= 0 ? 1 : 0);
-	pattern->setPattern(QString::fromLatin1("640"));
-	size640->setChecked( pattern->indexIn (tmp) >= 0 ? 1 : 0);
-	pattern->setPattern(QString::fromLatin1("800"));
-	size800->setChecked( pattern->indexIn (tmp)  >= 0 ? 1 : 0 );
-	pattern->setPattern(QString::fromLatin1("1024"));
-	size1024->setChecked( pattern->indexIn (tmp)  >= 0 ? 1 : 0);
-	pattern->setPattern(QString::fromLatin1("1280"));
-	size1280->setChecked( pattern->indexIn (tmp)  >= 0 ? 1 : 0);
-	pattern->setPattern(QString::fromLatin1("1600"));
-	size1600->setChecked( pattern->indexIn (tmp)  >= 0 ? 1 : 0);
-	pattern->setPattern(QString::fromLatin1("-1"));
-	sizeOrig->setChecked( pattern->indexIn (tmp)  >= 0 ? 1 : 0);
+    QStringMatcher* pattern = new QStringMatcher(QString::fromLatin1("320"));
+    size320->setChecked( pattern->indexIn (tmp) >= 0 ? 1 : 0);
+    pattern->setPattern(QString::fromLatin1("640"));
+    size640->setChecked( pattern->indexIn (tmp) >= 0 ? 1 : 0);
+    pattern->setPattern(QString::fromLatin1("800"));
+    size800->setChecked( pattern->indexIn (tmp)  >= 0 ? 1 : 0 );
+    pattern->setPattern(QString::fromLatin1("1024"));
+    size1024->setChecked( pattern->indexIn (tmp)  >= 0 ? 1 : 0);
+    pattern->setPattern(QString::fromLatin1("1280"));
+    size1280->setChecked( pattern->indexIn (tmp)  >= 0 ? 1 : 0);
+    pattern->setPattern(QString::fromLatin1("1600"));
+    size1600->setChecked( pattern->indexIn (tmp)  >= 0 ? 1 : 0);
+    pattern->setPattern(QString::fromLatin1("-1"));
+    sizeOrig->setChecked( pattern->indexIn (tmp)  >= 0 ? 1 : 0);
     } else
-	size800->setChecked( 1 );
+    size800->setChecked( 1 );
 
     _cbs << size800 << size1024 << size1280 << size640 << size1600 << size320 << sizeOrig;
 
@@ -415,10 +415,10 @@ QString HTMLDialog::activeSizes() const
     QString res;
     for( QList<ImageSizeCheckBox*>::ConstIterator sizeIt = _cbs.begin(); sizeIt != _cbs.end(); ++sizeIt ) {
         if ( (*sizeIt)->isChecked() ) {
-	    if (res.length() > 0)
-		res.append(QString::fromLatin1(","));
+        if (res.length() > 0)
+        res.append(QString::fromLatin1(","));
             res.append(QString::number((*sizeIt)->width()));
-	}
+    }
     }
     return res;
 }
@@ -430,12 +430,12 @@ QString HTMLDialog::includeSelections() const
 
     for( QMap<QString,QCheckBox*>::ConstIterator it = _whatToIncludeMap.begin();
          it != _whatToIncludeMap.end(); ++it ) {
-	QString name = it.key();
+    QString name = it.key();
         if ( _setup.includeCategory(name) ) {
-	    if (sel.length() > 0)
-		sel.append(QString::fromLatin1(","));
+        if (sel.length() > 0)
+        sel.append(QString::fromLatin1(","));
             sel.append(name);
-	}
+    }
     }
     return sel;
 }
@@ -468,8 +468,8 @@ void HTMLDialog::populateThemesCombo()
             _themes.insert( i, themePath );
             
             if (themeDefault == QString::fromLatin1("true")) {
-		theme = i;
-		defaultthemes++;
+        theme = i;
+        defaultthemes++;
             }
             i++;
         }
@@ -489,7 +489,7 @@ void HTMLDialog::populateThemesCombo()
 void HTMLDialog::displayThemeDescription(int themenr)
 {
    // SLOT: update _themeInfo label whenever the _theme QComboBox changes.
-   QString outtxt = i18n( "by " );
+   QString outtxt = i18nc( "This is to show the author of the theme. E.g. copyright character (&#169;) by itself will work fine on this context if no proper word is available in your language.", "by " );
    outtxt.append( _themeAuthors[themenr] );
    outtxt.append( i18n( "\n " ) );
    outtxt.append( _themeDescriptions[themenr] );
@@ -498,7 +498,7 @@ void HTMLDialog::displayThemeDescription(int themenr)
    // however, storing author and descriptions separately might be cleaner.
 }
 
-int HTMLDialog::exec(const DB::IdList& list)
+int HTMLDialog::exec(const DB::FileNameList& list)
 {
     _list = list;
     return KDialog::exec();
@@ -525,7 +525,7 @@ Setup HTMLGenerator::HTMLDialog::setup() const
          includeIt != _whatToIncludeMap.end(); ++includeIt ) {
         setup.setIncludeCategory( includeIt.key(), includeIt.value()->isChecked() );
     }
-    setup.setImageList( _list );
+    setup.setImageList(_list);
 
     setup.setResolutions( activeResolutions() );
     setup.setInlineMovies( _inlineMovies->isChecked() );
@@ -533,3 +533,4 @@ Setup HTMLGenerator::HTMLDialog::setup() const
 }
 
 #include "HTMLDialog.moc"
+// vi:expandtab:tabstop=4 shiftwidth=4:
