@@ -18,13 +18,9 @@
 #ifndef DATABASEBACKENDPAGE_H
 #define DATABASEBACKENDPAGE_H
 #include <QWidget>
-class Q3ButtonGroup;
 class QCheckBox;
 class QSpinBox;
 
-namespace SQLDB { class SQLSettingsWidget; }
-
-
 namespace Settings
 {
 class SettingsData;
@@ -45,11 +41,10 @@ private:
     QSpinBox* _backupCount;
     QCheckBox* _compressBackup;
     QCheckBox* _compressedIndexXML;
-    Q3ButtonGroup* _backendButtons;
-    SQLDB::SQLSettingsWidget* _sqlSettings;
 };
 
 }
 
 #endif /* DATABASEBACKENDPAGE_H */
 
+// vi:expandtab:tabstop=4 shiftwidth=4:
