@@ -40,13 +40,6 @@
 #include "DB/MemberMap.h"
 #include "Utilities/Util.h"
 
-#include "config-kpa-sqldb.h"
-#ifdef SQLDB_SUPPORT
-#  include "SQLDB/ConfigFileHandler.h"
-#  include "SQLDB/DatabaseAddress.h"
-#  include "SQLDB/QueryErrors.h"
-#endif
-
 #define STR(x) QString::fromLatin1(x)
 
 #define value( GROUP, OPTION, DEFAULT )                            \
@@ -149,7 +142,6 @@ SettingsData::SettingsData( const QString& imageDirectory )
 //// General ////
 /////////////////
 
-property_ref ( backend               , setBackend               , QString       , General, QString::fromLatin1("xml") )
 property_copy( useEXIFRotate         , setUseEXIFRotate         , bool          , General, true                       )
 property_copy( useEXIFComments       , setUseEXIFComments       , bool          , General, true                       )
 property_copy( searchForImagesOnStart, setSearchForImagesOnStart, bool          , General, true                       )
@@ -169,6 +161,7 @@ property_copy( excludeDirectories    , setExcludeDirectories    , QString
 
 getValueFunc( QSize,histogramSize,  General,QSize(15,30) )
 getValueFunc( ViewSortType,viewSortType,  General,(int)SortLastUse )
+getValueFunc( AnnotationDialog::MatchType, matchType,  General,(int)AnnotationDialog::MatchFromWordStart )
 
 void SettingsData::setHistogramSize( const QSize& size )
 {
@@ -187,6 +180,14 @@ void SettingsData::setViewSortType( const ViewSortType tp )
     setValue( "General", "viewSortType", (int)tp );
     emit viewSortTypeChanged( tp );
 }
+void SettingsData::setMatchType( const AnnotationDialog::MatchType mt )
+{
+    if ( mt == matchType() )
+        return;
+
+    setValue( "General", "matchType", (int)mt );
+    emit matchTypeChanged( mt );
+}
 
 bool SettingsData::trustTimeStamps()
 {
@@ -224,8 +225,8 @@ property_copy( modifiedFileComponent , setModifiedFileComponent , QString
 property_copy( originalFileComponent , setOriginalFileComponent , QString       , FileVersionDetection, QString()           )
 property_copy( moveOriginalContents  , setMoveOriginalContents  , bool          , FileVersionDetection, false               )
 property_copy( autoStackNewFiles     , setAutoStackNewFiles     , bool          , FileVersionDetection, true                )
-property_copy( copyFileComponent     , setCopyFileComponent     , QString       , FileVersionDetection, QString()           )
-property_copy( copyFileReplacementComponent , setCopyFileReplacementComponent , QString  , FileVersionDetection, QString()  )
+property_copy( copyFileComponent     , setCopyFileComponent     , QString       , FileVersionDetection, "(.[^.]+)$"         )
+property_copy( copyFileReplacementComponent , setCopyFileReplacementComponent , QString  , FileVersionDetection, "-edited\\1")
 
 ////////////////////
 //// Thumbnails ////
@@ -263,6 +264,7 @@ property_copy( showLabel                , setShowLabel                , bool
 property_copy( showDescription          , setShowDescription          , bool            , Viewer, true           )
 property_copy( showDate                 , setShowDate                 , bool            , Viewer, true           )
 property_copy( showImageSize            , setShowImageSize            , bool            , Viewer, true           )
+property_copy( showRating               , setShowRating                , bool            , Viewer, true           )
 property_copy( showTime                 , setShowTime                 , bool            , Viewer, true           )
 property_copy( showFilename             , setShowFilename             , bool            , Viewer, false          )
 property_copy( showEXIF                 , setShowEXIF                 , bool            , Viewer, true           )
@@ -326,29 +328,6 @@ property_copy( useModDateIfNoExif       , setUseModDateIfNoExif       , bool , E
 property_copy( updateOrientation        , setUpdateOrientation        , bool , ExifImport, false );
 property_copy( updateDescription        , setUpdateDescription        , bool , ExifImport, false );
 
-///////////////
-//// SQLDB ////
-///////////////
-
-#ifdef SQLDB_SUPPORT
-SQLDB::DatabaseAddress SettingsData::SQLParameters() const
-{
-    KConfigGroup config = KGlobal::config()->group(QString::fromLatin1("SQLDB"));
-    try {
-        return SQLDB::readConnectionParameters(config);
-    }
-    catch (SQLDB::DriverNotFoundError&) {}
-    return SQLDB::DatabaseAddress();
-}
-
-void SettingsData::setSQLParameters(const SQLDB::DatabaseAddress& address)
-{
-    KConfigGroup config = KGlobal::config()->group(QString::fromLatin1("SQLDB"));
-    SQLDB::writeConnectionParameters(address, config);
-    config.sync();
-}
-#endif /* SQLDB_SUPPORT */
-
 ///////////////////////
 //// Miscellaneous ////
 ///////////////////////
@@ -510,3 +489,4 @@ double Settings::SettingsData::getThumbnailAspectRatio() const
     }
     return ratio;
 }
+// vi:expandtab:tabstop=4 shiftwidth=4:
