@@ -20,7 +20,7 @@
 #include "Settings/SettingsData.h"
 #include "DB/ImageInfo.h"
 #include "ImageManager/ImageDecoder.h"
-#include "ImageManager/Manager.h"
+#include "ImageManager/AsyncLoader.h"
 #include <klocale.h>
 #include <qfileinfo.h>
 
@@ -98,7 +98,7 @@ QString Utilities::createInfoText( DB::ImageInfoPtr info, QMap< int,QPair<QStrin
 
     QString result;
     if ( Settings::SettingsData::instance()->showFilename() ) {
-        AddNonEmptyInfo(i18n("<b>File Name: </b> "), info->fileName(DB::AbsolutePath), &result);
+        AddNonEmptyInfo(i18n("<b>File Name: </b> "), info->fileName().relative(), &result);
     }
 
     if ( Settings::SettingsData::instance()->showDate() )  {
@@ -106,25 +106,25 @@ QString Utilities::createInfoText( DB::ImageInfoPtr info, QMap< int,QPair<QStrin
                         &result);
     }
 
+    /* XXX */
     if ( Settings::SettingsData::instance()->showImageSize() && info->mediaType() == DB::Image)  {
         const QSize imageSize = info->size();
         // Do not add -1 x -1 text
         if (imageSize.width() >= 0 && imageSize.height() >= 0) {
             const double megapix = imageSize.width() * imageSize.height() / 1000000.0;
-            QString info =
-                QString::number(imageSize.width()) + i18n("x") +
-                QString::number(imageSize.height());
+            QString info = i18nc("width x height","%1x%2")
+                .arg(QString::number(imageSize.width()))
+                .arg(QString::number(imageSize.height()));
             if (megapix > 0.05) {
-                info +=
-                    QString::fromLatin1(" (") + QString::number(megapix, 'f', 1) +
-                    i18nc("Short for Mega Pixels", "MP") + QString::fromLatin1(")");
+                info += i18nc("short for: x megapixels"," (%1MP)")
+                    .arg(QString::number(megapix, 'f', 1));
             }
             AddNonEmptyInfo(i18n("<b>Image Size: </b> "), info, &result);
         }
     }
 
 #ifdef HAVE_NEPOMUK
-    if ( true /* FIXME */ ) {
+    if ( Settings::SettingsData::instance()->showRating() ) {
         if ( info->rating() != -1 ) {
             if ( ! result.isEmpty() )
                 result += QString::fromLatin1("<br/>");
@@ -178,7 +178,7 @@ QString Utilities::createInfoText( DB::ImageInfoPtr info, QMap< int,QPair<QStrin
     if ( Settings::SettingsData::instance()->showEXIF() ) {
         typedef QMap<QString,QStringList> ExifMap;
         typedef ExifMap::const_iterator ExifMapIterator;
-        ExifMap exifMap = Exif::Info::instance()->infoForViewer( info->fileName(DB::AbsolutePath), Settings::SettingsData::instance()->iptcCharset() );
+        ExifMap exifMap = Exif::Info::instance()->infoForViewer( info->fileName(), Settings::SettingsData::instance()->iptcCharset() );
 
         for( ExifMapIterator exifIt = exifMap.constBegin(); exifIt != exifMap.constEnd(); ++exifIt ) {
             if ( exifIt.key().startsWith( QString::fromAscii( "Exif." ) ) )
@@ -231,7 +231,7 @@ void Utilities::checkForBackupFile( const QString& fileName, const QString& mess
                 "Should the autosave file be used?", backupName, fileName, backUpFile.size() >> 10 ),
                 i18n("Found Autosave File") );
     else if ( backUpFile.size() > 0 )
-        code = KMessageBox::warningYesNo( 0,i18n( "<p>Error: %2</p>"
+        code = KMessageBox::warningYesNo( 0,i18n( "<p>Error: Cannot use current database file '%1':</p><p>%2</p>"
                 "<p>Do you want to use autosave (%3 - size %4 KB) instead of exiting?</p>"
                 "<p><small>(Manually verifying and copying the file might be a good idea)</small></p>", fileName, message, backupName, backUpFile.size() >> 10 ),
                 i18n("Recover from Autosave?") );
@@ -277,7 +277,7 @@ void Utilities::copyList( const QStringList& from, const QString& directoryTo )
 
 QString Utilities::setupDemo()
 {
-    QString dir = QString::fromLatin1( "/tmp/kphotoalbum-demo-" ) + QString::fromLocal8Bit( qgetenv( "LOGNAME" ) );
+    QString dir = QString::fromLatin1( "%1/kphotoalbum-demo-%2" ).arg(QDir::tempPath()).arg(QString::fromLocal8Bit( qgetenv( "LOGNAME" ) ));
     QFileInfo fi(dir);
     if ( ! fi.exists() ) {
         bool ok = QDir().mkdir( dir );
@@ -329,28 +329,9 @@ QString Utilities::setupDemo()
 
 bool Utilities::copy( const QString& from, const QString& to )
 {
-    QFile in( from );
-    QFile out( to );
-
-    if ( !in.open(QIODevice::ReadOnly) ) {
-        kWarning() << "Couldn't open " << from << " for reading\n";
-        return false;
-    }
-    if ( !out.open(QIODevice::WriteOnly) ) {
-        kWarning() << "Couldn't open " << to << " for writing\n";
-        in.close();
-        return false;
-    }
-
-    char buf[4096];
-    while( !in.atEnd() ) {
-        unsigned long int len = in.read( buf, sizeof(buf));
-        out.write( buf, len );
-    }
-
-    in.close();
-    out.close();
-    return true;
+    if ( QFileInfo(to).exists())
+        QDir().remove(to);
+    return QFile::copy(from,to);
 }
 
 bool Utilities::makeHardLink( const QString& from, const QString& to )
@@ -369,10 +350,10 @@ bool Utilities::makeSymbolicLink( const QString& from, const QString& to )
         return true;
 }
 
-bool Utilities::canReadImage( const QString& fileName )
+bool Utilities::canReadImage( const DB::FileName& fileName )
 {
-	bool fastMode = !Settings::SettingsData::instance()->ignoreFileExtension();
-    return ! KImageIO::typeForMime( KMimeType::findByPath( fileName, 0, fastMode )->name() ).isEmpty() ||
+    bool fastMode = !Settings::SettingsData::instance()->ignoreFileExtension();
+    return ! KImageIO::typeForMime( KMimeType::findByPath( fileName.absolute(), 0, fastMode )->name() ).isEmpty() ||
         ImageManager::ImageDecoder::mightDecode( fileName );
     // KMimeType::findByPath() never returns null pointer
 }
@@ -429,9 +410,9 @@ namespace Utilities
     bool loadJPEG(QImage *img, FILE* inputFile, QSize* fullSize, int dim );
 }
 
-bool Utilities::loadJPEG(QImage *img, const QString& imageFile, QSize* fullSize, int dim)
+bool Utilities::loadJPEG(QImage *img, const DB::FileName& imageFile, QSize* fullSize, int dim)
 {
-    FILE* inputFile=fopen( QFile::encodeName(imageFile), "rb");
+    FILE* inputFile=fopen( QFile::encodeName(imageFile.absolute()), "rb");
     if(!inputFile)
         return false;
     bool ok = loadJPEG( img, inputFile, fullSize, dim );
@@ -529,9 +510,9 @@ bool Utilities::loadJPEG(QImage *img, FILE* inputFile, QSize* fullSize, int dim
     return true;
 }
 
-bool Utilities::isJPEG( const QString& fileName )
+bool Utilities::isJPEG( const DB::FileName& fileName )
 {
-    QString format= QString::fromLocal8Bit( QImageReader::imageFormat( fileName ) );
+    QString format= QString::fromLocal8Bit( QImageReader::imageFormat( fileName.relative() ) );
     return format == QString::fromLocal8Bit( "jpeg" );
 }
 
@@ -554,22 +535,7 @@ QString dereferenceSymLinks( const QString& fileName )
 }
 }
 
-bool Utilities::areSameFile( const QString fileName1, const QString fileName2 )
-{
-    if (fileName1 == fileName2)
-        return true;
-
-    // If filenames are symbolic links, relative or contain more than
-    // one consecutive slashes, above test won't work, so try with
-    // normalized filenames.
-    return (normalizedFileName(dereferenceSymLinks(fileName1)) ==
-            normalizedFileName(dereferenceSymLinks(fileName2)));
-
-    // FIXME: Hard links. Different paths to same file (with symlinks)
-    // Maybe use inode numbers to solve those problems?
-}
-
-QString Utilities::stripSlash( const QString& fileName )
+QString Utilities::stripEndingForwardSlash( const QString& fileName )
 {
     if ( fileName.endsWith( QString::fromLatin1( "/" ) ) )
         return fileName.left( fileName.length()-1);
@@ -594,22 +560,12 @@ bool Utilities::runningDemo()
 
 void Utilities::deleteDemo()
 {
-    QString dir = QString::fromLatin1( "/tmp/kphotoalbum-demo-" ) + QString::fromLocal8Bit( qgetenv( "LOGNAME" ) );
+    QString dir = QString::fromLatin1( "%1/kphotoalbum-demo-%2" ).arg(QDir::tempPath()).arg(QString::fromLocal8Bit( qgetenv( "LOGNAME" ) ) );
     KUrl url;
     url.setPath( dir );
     (void) KIO::NetAccess::del( dir, MainWindow::Window::theMainWindow() );
 }
 
-// PENDING(blackie) delete this method
-QStringList Utilities::infoListToStringList( const DB::ImageInfoList& list )
-{
-    QStringList result;
-    for( DB::ImageInfoListConstIterator it = list.constBegin(); it != list.constEnd(); ++it ) {
-        result.append( (*it)->fileName(DB::AbsolutePath) );
-    }
-    return result;
-}
-
 QString Utilities::stripImageDirectory( const QString& fileName )
 {
     if ( fileName.startsWith( Settings::SettingsData::instance()->imageDirectory() ) )
@@ -620,7 +576,7 @@ QString Utilities::stripImageDirectory( const QString& fileName )
 
 QString Utilities::absoluteImageFileName( const QString& relativeName )
 {
-    return stripSlash( Settings::SettingsData::instance()->imageDirectory() ) + QString::fromLatin1( "/" ) + relativeName;
+    return stripEndingForwardSlash( Settings::SettingsData::instance()->imageDirectory() ) + QString::fromLatin1( "/" ) + relativeName;
 }
 
 QString Utilities::imageFileNameToAbsolute( const QString& fileName )
@@ -635,14 +591,6 @@ QString Utilities::imageFileNameToAbsolute( const QString& fileName )
         return absoluteImageFileName( fileName );
 }
 
-QString Utilities::imageFileNameToRelative( const QString& fileName )
-{
-    QRegExp regexp( QString::fromLatin1( "^/*" ) );
-    // A bit back and forth, but this function is to go away anyway (hzeller).
-    QString s = imageFileNameToAbsolute(fileName).mid( Settings::SettingsData::instance()->imageDirectory().length());
-    return s.replace( regexp, QString::fromLatin1( "" ) );
-}
-
 bool operator>( const QPoint& p1, const QPoint& p2)
 {
     return p1.y() > p2.y() || (p1.y() == p2.y() && p1.x() > p2.x() );
@@ -653,7 +601,7 @@ bool operator<( const QPoint& p1, const QPoint& p2)
     return p1.y() < p2.y() || ( p1.y() == p2.y() && p1.x() < p2.x() );
 }
 
-bool Utilities::isVideo( const QString& fileName )
+bool Utilities::isVideo( const DB::FileName& fileName )
 {
     static StringSet videoExtensions;
     if ( videoExtensions.empty() ) {
@@ -686,12 +634,12 @@ bool Utilities::isVideo( const QString& fileName )
         videoExtensions.insert( QString::fromLatin1( "ogv" ) );
     }
 
-    QFileInfo fi( fileName );
+    QFileInfo fi( fileName.relative() );
     QString ext = fi.suffix().toLower();
     return videoExtensions.contains( ext );
 }
 
-bool Utilities::isRAW( const QString& fileName )
+bool Utilities::isRAW( const DB::FileName& fileName )
 {
     return ImageManager::RAWImageDecoder::isRAW( fileName );
 }
@@ -715,9 +663,9 @@ QString Utilities::cStringWithEncoding( const char *c_str, const QString& charse
     return codec->toUnicode( c_str );
 }
 
-DB::MD5 Utilities::MD5Sum( const QString& fileName )
+DB::MD5 Utilities::MD5Sum( const DB::FileName& fileName )
 {
-    QFile file( fileName );
+    QFile file( fileName.absolute() );
     if ( !file.open( QIODevice::ReadOnly ) )
         return DB::MD5();
 
@@ -734,3 +682,12 @@ QColor Utilities::contrastColor( const QColor& col )
     else
         return Qt::black;
 }
+
+void Utilities::saveImage( const DB::FileName& fileName, const QImage& image, const char* format )
+{
+    const QFileInfo info(fileName.absolute());
+    QDir().mkpath(info.path());
+    const bool ok = image.save(fileName.absolute(),format);
+    Q_ASSERT(ok); Q_UNUSED(ok);
+}
+// vi:expandtab:tabstop=4 shiftwidth=4:
