@@ -16,7 +16,6 @@
    Boston, MA 02110-1301, USA.
 */
 
-
 #include "ImageDisplay.h"
 #include <qpainter.h>
 #include <QPaintEvent>
@@ -26,7 +25,7 @@
 #include <klocale.h>
 #include "Settings/SettingsData.h"
 #include "Viewer/ViewHandler.h"
-#include "ImageManager/Manager.h"
+#include "ImageManager/AsyncLoader.h"
 #include <qcursor.h>
 #include <qapplication.h>
 #include <math.h>
@@ -70,11 +69,10 @@
 */
 
 Viewer::ImageDisplay::ImageDisplay( QWidget* parent)
-    :Display( parent ), _reloadImageInProgress( false ), _forward(true), _curIndex(0),_busy( false ),
+    :AbstractDisplay( parent ), _reloadImageInProgress( false ), _forward(true), _curIndex(0),_busy( false ),
     _cursorHiding(true)
 {
     _viewHandler = new ViewHandler( this );
-    _cache.setAutoDelete( true );
 
     setMouseTracking( true );
     _cursorTimer = new QTimer( this );
@@ -89,7 +87,7 @@ Viewer::ImageDisplay::ImageDisplay( QWidget* parent)
  */
 void Viewer::ImageDisplay::hideCursor() {
     if (_cursorHiding)
-        setCursor( Qt::blankCursor );
+        setCursor( Qt::BlankCursor );
 }
 
 /**
@@ -166,18 +164,18 @@ bool Viewer::ImageDisplay::setImage( DB::ImageInfoPtr info, bool forward )
 
     // Find the index of the current image
     _curIndex = 0;
-    for( QStringList::Iterator it = _imageList.begin(); it != _imageList.end(); ++it ) {
-        if ( *it == info->fileName(DB::AbsolutePath) )
+    for( DB::FileNameList::Iterator it = _imageList.begin(); it != _imageList.end(); ++it ) {
+        if ( *it == info->fileName() )
             break;
         ++_curIndex;
     }
 
-    ViewPreloadInfo* found = _cache[_curIndex];
-    if ( found && found->angle == info->angle() ) {
-        _loadedImage = found->img;
-        updateZoomPoints( Settings::SettingsData::instance()->viewerStandardSize(), found->img.size() );
+    if ( _cache.contains(_curIndex) && _cache[_curIndex].angle == info->angle()) {
+        const ViewPreloadInfo& found = _cache[_curIndex];
+        _loadedImage = found.img;
+        updateZoomPoints( Settings::SettingsData::instance()->viewerStandardSize(), found.img.size() );
         cropAndScale();
-        info->setSize( found->size );
+        info->setSize( found.size );
         emit imageReady();
     }
     else {
@@ -192,8 +190,8 @@ bool Viewer::ImageDisplay::setImage( DB::ImageInfoPtr info, bool forward )
 
 void Viewer::ImageDisplay::resizeEvent( QResizeEvent* event )
 {
-    ImageManager::Manager::instance()->stop( this, ImageManager::StopOnlyNonPriorityLoads );
-    _cache.fill(0); // Clear the cache
+    ImageManager::AsyncLoader::instance()->stop( this, ImageManager::StopOnlyNonPriorityLoads );
+    _cache.clear();
     if ( _info ) {
         cropAndScale();
         if ( event->size().width() > 1.5*this->_loadedImage.size().width() || event->size().height() > 1.5*this->_loadedImage.size().height() )
@@ -518,10 +516,10 @@ bool Viewer::ImageDisplay::isImageZoomed( const Settings::StandardViewSize type,
     return false;
 }
 
-void Viewer::ImageDisplay::pixmapLoaded( const QString& fileName, const QSize& imgSize, const QSize& fullSize, int angle,
+void Viewer::ImageDisplay::pixmapLoaded( const DB::FileName& fileName, const QSize& imgSize, const QSize& fullSize, int angle,
                                          const QImage& img, const bool loadedOK)
 {
-    if ( loadedOK && fileName == _info->fileName(DB::AbsolutePath) ) {
+    if ( loadedOK && fileName == _info->fileName() ) {
         if ( fullSize.isValid() && !_info->size().isValid() )
             _info->setSize( fullSize );
 
@@ -548,25 +546,23 @@ void Viewer::ImageDisplay::pixmapLoaded( const QString& fileName, const QSize& i
         if ( imgSize != size() )
             return; // Might be an old preload version, or a loaded version that never made it in time
 
-        ViewPreloadInfo* info = new ViewPreloadInfo( img, fullSize, angle );
-        bool ok = _cache.insert( indexOf(fileName), info );
-        if ( !ok )
-            delete info;
+        ViewPreloadInfo info( img, fullSize, angle );
+        _cache.insert( indexOf(fileName), info );
         updatePreload();
     }
     unbusy();
     emit possibleChange();
 }
 
-void Viewer::ImageDisplay::setImageList( const QStringList& list )
+void Viewer::ImageDisplay::setImageList( const DB::FileNameList& list )
 {
     _imageList = list;
-    _cache.fill( 0, list.count() );
+    _cache.clear();
 }
 
 void Viewer::ImageDisplay::updatePreload()
 {
-    uint cacheSize = ( Settings::SettingsData::instance()->viewerCacheSize() * 1024 * 1024 ) / (width()*height()*4);
+    const int cacheSize = ( Settings::SettingsData::instance()->viewerCacheSize() * 1024 * 1024 ) / (width()*height()*4);
     bool cacheFull = (_cache.count() > cacheSize);
 
     int incr = ( _forward ? 1 : -1 );
@@ -576,13 +572,13 @@ void Viewer::ImageDisplay::updatePreload()
         if ( _forward ? ( i >= (int) _imageList.count() ) : (i < 0) )
             break;
 
-        DB::ImageInfoPtr info = DB::ImageDB::instance()->info(_imageList[i], DB::AbsolutePath);
+        DB::ImageInfoPtr info = DB::ImageDB::instance()->info(_imageList[i]);
         if ( !info ) {
             qWarning("Info was null for index %d!", i);
             return;
         }
 
-        if ( _cache[i] ) {
+        if ( _cache.contains(i) ) {
             nextOnesInCache++;
             if ( nextOnesInCache >= ceil(cacheSize/2.0) && cacheFull ) {
                 // Ok enough images in cache
@@ -599,7 +595,7 @@ void Viewer::ImageDisplay::updatePreload()
                 for ( int j = ( _forward ? 0 : _imageList.count() -1 );
                       j != _curIndex;
                       j += ( _forward ? 1 : -1 ) ) {
-                    if ( _cache[j] ) {
+                    if ( _cache.contains(j) ) {
                         _cache.remove(j);
                         return;
                     }
@@ -609,7 +605,7 @@ void Viewer::ImageDisplay::updatePreload()
                 for ( int j = ( _forward ? _imageList.count() -1 : 0 );
                       j != _curIndex;
                       j += ( _forward ? -1 : 1 ) ) {
-                    if ( _cache[j] ) {
+                    if ( _cache.contains(j) ) {
                         _cache.remove(j);
                         return;
                     }
@@ -624,10 +620,10 @@ void Viewer::ImageDisplay::updatePreload()
 }
 
 
-int Viewer::ImageDisplay::indexOf( const QString& fileName )
+int Viewer::ImageDisplay::indexOf( const DB::FileName& fileName )
 {
     int i = 0;
-    for( QStringList::ConstIterator it = _imageList.constBegin(); it != _imageList.constEnd(); ++it ) {
+    for( DB::FileNameList::ConstIterator it = _imageList.constBegin(); it != _imageList.constEnd(); ++it ) {
         if ( *it == fileName )
             break;
         ++i;
@@ -689,9 +685,9 @@ void Viewer::ImageDisplay::updateZoomPoints( const Settings::StandardViewSize ty
 void Viewer::ImageDisplay::potentialyLoadFullSize()
 {
     if ( _info->size() != _loadedImage.size() ) {
-        ImageManager::ImageRequest* request = new ImageManager::ImageRequest( _info->fileName(DB::AbsolutePath), QSize(-1,-1), _info->angle(), this );
+        ImageManager::ImageRequest* request = new ImageManager::ImageRequest( _info->fileName(), QSize(-1,-1), _info->angle(), this );
         request->setPriority( ImageManager::Viewer );
-        ImageManager::Manager::instance()->load( request );
+        ImageManager::AsyncLoader::instance()->load( request );
         busy();
         _reloadImageInProgress = true;
     }
@@ -717,10 +713,10 @@ void Viewer::ImageDisplay::requestImage( const DB::ImageInfoPtr& info, bool prio
     if ( viewSize == Settings::NaturalSize )
         s = QSize(-1,-1);
 
-    ImageManager::ImageRequest* request = new ImageManager::ImageRequest( info->fileName(DB::AbsolutePath), s, info->angle(), this );
+    ImageManager::ImageRequest* request = new ImageManager::ImageRequest( info->fileName(), s, info->angle(), this );
     request->setUpScale( viewSize == Settings::FullSize );
     request->setPriority( priority ? ImageManager::Viewer : ImageManager::ViewerPreload );
-    ImageManager::Manager::instance()->load( request );
+    ImageManager::AsyncLoader::instance()->load( request );
 }
 
 void Viewer::ImageDisplay::hideEvent(QHideEvent *)
@@ -729,3 +725,4 @@ void Viewer::ImageDisplay::hideEvent(QHideEvent *)
 }
 
 #include "ImageDisplay.moc"
+// vi:expandtab:tabstop=4 shiftwidth=4:
